@@ -37,13 +37,14 @@ func Test_Servers_GetServers_OK(t *testing.T) {
 	"netmask_v4":"255.255.254.0","gateway_v4":"192.168.1.1","power_status":"down","VPSPLANID":"31",
 	"v6_networks": [{"v6_network": "2002:DB9:1000::", "v6_main_ip": "2000:DB8:1000::0000", "v6_network_size": "32" }],
 	"label":"test beta","internal_ip":"10.10.10.10",
-	"kvm_url":"https:\/\/my.vultr.com\/subs\/vps\/novnc\/api.php?data=456","auto_backups":"yes", "OSID": "127", "APPID": "0"},
+	"kvm_url":"https:\/\/my.vultr.com\/subs\/vps\/novnc\/api.php?data=456","auto_backups":"yes", "OSID": "127", "APPID": "2",
+	"FIREWALLGROUPID": "1a"},
 "9753721":{"SUBID":"9753721","os":"Ubuntu 14.04 x64","ram":"768 MB","disk":"Virtual 15 GB","main_ip":"123.456.789.0",
 	"vcpu_count":"2","location":"Frankfurt","DCID":"9","default_password":"oops!","date_created":"2017-07-07 07:07:07",
 	"pending_charges":0.04,"status":"active","cost_per_month":"5.00","current_bandwidth_gb":7,"allowed_bandwidth_gb":"1000",
 	"netmask_v4":"255.255.255.0","gateway_v4":"123.456.789.1","power_status":"running","VPSPLANID":"29",
 	"label":"test alpha","internal_ip":"",
-	"kvm_url":"https:\/\/my.vultr.com\/subs\/vps\/novnc\/api.php?data=123","auto_backups":"no"}}`)
+	"kvm_url":"https:\/\/my.vultr.com\/subs\/vps\/novnc\/api.php?data=123","auto_backups":"no", "APPID": "0"}}`)
 	defer server.Close()
 
 	servers, err := client.GetServers()
@@ -71,6 +72,7 @@ func Test_Servers_GetServers_OK(t *testing.T) {
 		assert.Equal(t, 1000.0, servers[0].AllowedBandwidth)
 		assert.Equal(t, "", servers[0].OSID)
 		assert.Equal(t, "", servers[0].AppID)
+		assert.Equal(t, "", servers[0].FirewallGroupID)
 
 		assert.Equal(t, "789032", servers[1].ID)
 		assert.Equal(t, "test beta", servers[1].Name)
@@ -87,7 +89,8 @@ func Test_Servers_GetServers_OK(t *testing.T) {
 		assert.Equal(t, `https://my.vultr.com/subs/vps/novnc/api.php?data=456`, servers[1].KVMUrl)
 		assert.Equal(t, "yes", servers[1].AutoBackups)
 		assert.Equal(t, "127", servers[1].OSID)
-		assert.Equal(t, "0", servers[1].AppID)
+		assert.Equal(t, "2", servers[1].AppID)
+		assert.Equal(t, "1a", servers[1].FirewallGroupID)
 	}
 }
 
@@ -293,6 +296,23 @@ func Test_Servers_RenameServer_OK(t *testing.T) {
 	assert.Nil(t, client.RenameServer("123456789", "new-name"))
 }
 
+func Test_Servers_TagServer_Error(t *testing.T) {
+	server, client := getTestServerAndClient(http.StatusNotAcceptable, `{error}`)
+	defer server.Close()
+
+	err := client.TagServer("123456789", "new-tag")
+	if assert.NotNil(t, err) {
+		assert.Equal(t, `{error}`, err.Error())
+	}
+}
+
+func Test_Servers_TagServer_OK(t *testing.T) {
+	server, client := getTestServerAndClient(http.StatusOK, `{no-response?!}`)
+	defer server.Close()
+
+	assert.Nil(t, client.TagServer("123456789", "new-tag"))
+}
+
 func Test_Servers_StartServer_Error(t *testing.T) {
 	server, client := getTestServerAndClient(http.StatusNotAcceptable, `{error}`)
 	defer server.Close()
@@ -378,6 +398,40 @@ func Test_Servers_DeleteServer_OK(t *testing.T) {
 	assert.Nil(t, client.DeleteServer("123456789"))
 }
 
+func Test_Servers_SetFirewallGroup_Error(t *testing.T) {
+	server, client := getTestServerAndClient(http.StatusNotAcceptable, `{error}`)
+	defer server.Close()
+
+	err := client.SetFirewallGroup("123456789", "123456789")
+	if assert.NotNil(t, err) {
+		assert.Equal(t, `{error}`, err.Error())
+	}
+}
+
+func Test_Servers_SetFirewallGroup_OK(t *testing.T) {
+	server, client := getTestServerAndClient(http.StatusOK, `{no-response?!}`)
+	defer server.Close()
+
+	assert.Nil(t, client.SetFirewallGroup("123456789", "123456789"))
+}
+
+func Test_Servers_UnsetFirewallGroup_Error(t *testing.T) {
+	server, client := getTestServerAndClient(http.StatusNotAcceptable, `{error}`)
+	defer server.Close()
+
+	err := client.UnsetFirewallGroup("123456789")
+	if assert.NotNil(t, err) {
+		assert.Equal(t, `{error}`, err.Error())
+	}
+}
+
+func Test_Servers_UnsetFirewallGroup_OK(t *testing.T) {
+	server, client := getTestServerAndClient(http.StatusOK, `{no-response?!}`)
+	defer server.Close()
+
+	assert.Nil(t, client.UnsetFirewallGroup("123456789"))
+}
+
 func Test_Servers_ChangeOSofServer_Error(t *testing.T) {
 	server, client := getTestServerAndClient(http.StatusNotAcceptable, `{error}`)
 	defer server.Close()
